==> Google-Ads-GoogleAds-Client-8.0.1.tar.gz: Google-Ads-GoogleAds-Client-8.0.1/lib/Google/Ads/GoogleAds/V8/Services/ConversionUploadService/ClickConversion.pm <==
# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V8::Services::ConversionUploadService::ClickConversion;

use strict;
use warnings;
use base qw(Google::Ads::GoogleAds::BaseEntity);

use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;

sub new {
  my ($class, $args) = @_;
  my $self = {
    cartData                => $args->{cartData},
    conversionAction        => $args->{conversionAction},
    conversionDateTime      => $args->{conversionDateTime},
    conversionValue         => $args->{conversionValue},
    currencyCode            => $args->{currencyCode},
    customVariables         => $args->{customVariables},
    externalAttributionData => $args->{externalAttributionData},
    gclid                   => $args->{gclid},
    orderId                 => $args->{orderId}};

  # Delete the unassigned fields in this object for a more concise JSON payload
  remove_unassigned_fields($self, $args);

  bless $self, $class;
  return $self;
}

1;

==> Google-Ads-GoogleAds-Client-10.0.0.tar.gz: Google-Ads-GoogleAds-Client-10.0.0/lib/Google/Ads/GoogleAds/V8/Services/ConversionUploadService/ClickConversion.pm <==
# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V8::Services::ConversionUploadService::ClickConversion;

use strict;
use warnings;
use base qw(Google::Ads::GoogleAds::BaseEntity);

use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;

sub new {
  my ($class, $args) = @_;
  my $self = {
    cartData                => $args->{cartData},
    conversionAction        => $args->{conversionAction},
    conversionDateTime      => $args->{conversionDateTime},
    conversionValue         => $args->{conversionValue},
    currencyCode            => $args->{currencyCode},
    customVariables         => $args->{customVariables},
    externalAttributionData => $args->{externalAttributionData},
    gclid                   => $args->{gclid},
    orderId                 => $args->{orderId},
    userIdentifiers         => $args->{userIdentifiers}};

  # Delete the unassigned fields in this object for a more concise JSON payload
  remove_unassigned_fields($self, $args);

  bless $self, $class;
  return $self;
}

1;
